==> jc-1.4.0.tar.gz: gnu/java/security/ber/BERValue.h <==
// public class gnu.java.security.ber.BERValue

// class file dependencies
// @dep_class b8c28491b694e0ca gnu_java_security_ber_BERValue
// @dep_class 6370ccdc23537458 gnu_java_security_der_DERValue
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_der_DERValue

#include "gnu/java/security/der/DERValue.h"

#ifndef _JC_gnu_java_security_ber_BERValue_H_
#define _JC_gnu_java_security_ber_BERValue_H_

// Forward structure declarations
struct _jc_gnu_java_security_der_DERValue$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_security_ber_BERValue$sub_refs	_jc_gnu_java_security_ber_BERValue$sub_refs;
typedef struct _jc_gnu_java_security_ber_BERValue$sub_nonrefs	_jc_gnu_java_security_ber_BERValue$sub_nonrefs;
typedef struct _jc_gnu_java_security_ber_BERValue$refs	_jc_gnu_java_security_ber_BERValue$refs;
typedef struct _jc_gnu_java_security_ber_BERValue$nonrefs	_jc_gnu_java_security_ber_BERValue$nonrefs;
typedef struct _jc_gnu_java_security_ber_BERValue$object	_jc_gnu_java_security_ber_BERValue$object;

typedef const struct _jc_gnu_java_security_ber_BERValue$vmethods	_jc_gnu_java_security_ber_BERValue$vmethods;
typedef const struct _jc_gnu_java_security_ber_BERValue$vtable	_jc_gnu_java_security_ber_BERValue$vtable;
typedef const struct _jc_gnu_java_security_ber_BERValue$vtype	_jc_gnu_java_security_ber_BERValue$vtype;

// Constructors
extern void _jc_gnu_java_security_ber_BERValue$method$_init$8e22e8011ae1da3a(_jc_env *, struct _jc_gnu_java_security_ber_BERValue$object *, jint, jint, struct _jc_java_lang_Object$object *, struct _jc_byte_array *);
extern void _jc_gnu_java_security_ber_BERValue$method$_init$964b4a8e45252143(_jc_env *, struct _jc_gnu_java_security_ber_BERValue$object *, jint, struct _jc_java_lang_Object$object *);
extern void _jc_gnu_java_security_ber_BERValue$method$_init$e235faa9f3db5510(_jc_env *, struct _jc_gnu_java_security_ber_BERValue$object *, jint, struct _jc_java_lang_Object$object *, struct _jc_byte_array *);

// Virtual methods
extern jboolean _jc_gnu_java_security_ber_BERValue$method$getIndefinite$3554ee95c3eeada1(_jc_env *, struct _jc_gnu_java_security_ber_BERValue$object *);
extern jint _jc_gnu_java_security_ber_BERValue$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_gnu_java_security_ber_BERValue$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_ber_BERValue$method_info$getIndefinite$3554ee95c3eeada1;
extern _jc_method _jc_gnu_java_security_ber_BERValue$method_info$getLength$b9eaa8ec0a00f23d;

// Static methods
extern jboolean _jc_gnu_java_security_ber_BERValue$method$isIndefinite$a35e38d456eaa106(_jc_env *, struct _jc_gnu_java_security_der_DERValue$object *);

// Virtual methods structure
struct _jc_gnu_java_security_ber_BERValue$vmethods {
	jboolean	(*getIndefinite$3554ee95c3eeada1)(_jc_env *, struct _jc_gnu_java_security_ber_BERValue$object *);
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_gnu_java_security_ber_BERValue$object *);
};

// Vtable
struct _jc_gnu_java_security_ber_BERValue$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_der_DERValue$vmethods	gnu_java_security_der_DERValue;
	_jc_gnu_java_security_ber_BERValue$vmethods	gnu_java_security_ber_BERValue;
};

// Vtype
struct _jc_gnu_java_security_ber_BERValue$vtype {
	_jc_type			type;
	_jc_gnu_java_security_ber_BERValue$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_ber_BERValue$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_ber_BERValue$refs {
    _jc_gnu_java_security_ber_BERValue$sub_refs	gnu_java_security_ber_BERValue;
    _jc_gnu_java_security_der_DERValue$sub_refs	gnu_java_security_der_DERValue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_ber_BERValue$sub_nonrefs {
	jboolean	indefinite;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_ber_BERValue$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_der_DERValue$sub_nonrefs	gnu_java_security_der_DERValue;
    _jc_gnu_java_security_ber_BERValue$sub_nonrefs	gnu_java_security_ber_BERValue;
};

// Object instance structure
struct _jc_gnu_java_security_ber_BERValue$object {
	_jc_gnu_java_security_ber_BERValue$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_ber_BERValue$vtype	*vtype;
	_jc_gnu_java_security_ber_BERValue$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_ber_BERValue$vtype _jc_gnu_java_security_ber_BERValue$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_ber_BERValue, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_ber_BERValue$class_object;

#endif	/* _JC_gnu_java_security_ber_BERValue_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/ber/BERValue.h <==
// public class gnu.java.security.ber.BERValue

// class file dependencies
// @dep_class b8c28491b694e0ca gnu_java_security_ber_BERValue
// @dep_class de1638783317796a gnu_java_security_der_DERValue
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_der_DERValue

#include "gnu/java/security/der/DERValue.h"

#ifndef _JC_gnu_java_security_ber_BERValue_H_
#define _JC_gnu_java_security_ber_BERValue_H_

// Forward structure declarations
struct _jc_gnu_java_security_der_DERValue$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_security_ber_BERValue$sub_refs	_jc_gnu_java_security_ber_BERValue$sub_refs;
typedef struct _jc_gnu_java_security_ber_BERValue$sub_nonrefs	_jc_gnu_java_security_ber_BERValue$sub_nonrefs;
typedef struct _jc_gnu_java_security_ber_BERValue$refs	_jc_gnu_java_security_ber_BERValue$refs;
typedef struct _jc_gnu_java_security_ber_BERValue$nonrefs	_jc_gnu_java_security_ber_BERValue$nonrefs;
typedef struct _jc_gnu_java_security_ber_BERValue$object	_jc_gnu_java_security_ber_BERValue$object;

typedef const struct _jc_gnu_java_security_ber_BERValue$vmethods	_jc_gnu_java_security_ber_BERValue$vmethods;
typedef const struct _jc_gnu_java_security_ber_BERValue$vtable	_jc_gnu_java_security_ber_BERValue$vtable;
typedef const struct _jc_gnu_java_security_ber_BERValue$vtype	_jc_gnu_java_security_ber_BERValue$vtype;

// Constructors
extern void _jc_gnu_java_security_ber_BERValue$method$_init$8e22e8011ae1da3a(_jc_env *, struct _jc_gnu_java_security_ber_BERValue$object *, jint, jint, struct _jc_java_lang_Object$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_ber_BERValue$method$_init$964b4a8e45252143(_jc_env *, struct _jc_gnu_java_security_ber_BERValue$object *, jint, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_ber_BERValue$method$_init$e235faa9f3db5510(_jc_env *, struct _jc_gnu_java_security_ber_BERValue$object *, jint, struct _jc_java_lang_Object$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_java_security_ber_BERValue$method$getIndefinite$3554ee95c3eeada1(_jc_env *, struct _jc_gnu_java_security_ber_BERValue$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_security_ber_BERValue$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_gnu_java_security_ber_BERValue$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_ber_BERValue$method_info$getIndefinite$3554ee95c3eeada1;
extern _jc_method _jc_gnu_java_security_ber_BERValue$method_info$getLength$b9eaa8ec0a00f23d;

// Static methods
extern jboolean _jc_gnu_java_security_ber_BERValue$method$isIndefinite$a35e38d456eaa106(_jc_env *, struct _jc_gnu_java_security_der_DERValue$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_ber_BERValue$vmethods {
	jboolean	(*getIndefinite$3554ee95c3eeada1)(_jc_env *, struct _jc_gnu_java_security_ber_BERValue$object *) _JC_JCNI_ATTR;
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_gnu_java_security_ber_BERValue$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_ber_BERValue$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_der_DERValue$vmethods	gnu_java_security_der_DERValue;
	_jc_gnu_java_security_ber_BERValue$vmethods	gnu_java_security_ber_BERValue;
};

// Vtype
struct _jc_gnu_java_security_ber_BERValue$vtype {
	_jc_type			type;
	_jc_gnu_java_security_ber_BERValue$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_ber_BERValue$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_ber_BERValue$refs {
    _jc_gnu_java_security_ber_BERValue$sub_refs	gnu_java_security_ber_BERValue;
    _jc_gnu_java_security_der_DERValue$sub_refs	gnu_java_security_der_DERValue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_ber_BERValue$sub_nonrefs {
	jboolean	indefinite;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_ber_BERValue$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_der_DERValue$sub_nonrefs	gnu_java_security_der_DERValue;
    _jc_gnu_java_security_ber_BERValue$sub_nonrefs	gnu_java_security_ber_BERValue;
};

// Object instance structure
struct _jc_gnu_java_security_ber_BERValue$object {
	_jc_gnu_java_security_ber_BERValue$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_ber_BERValue$vtype	*vtype;
	_jc_gnu_java_security_ber_BERValue$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_ber_BERValue$vtype _jc_gnu_java_security_ber_BERValue$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_ber_BERValue, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_ber_BERValue$class_object;

#endif	/* _JC_gnu_java_security_ber_BERValue_H_ */
